@@ -6,6 +6,7 @@ from typing import Optional
 import typer
 
 # first party
+from dbtc import __version__
 from dbtc import dbtCloudClient as dbtc
 from dbtc.console import console
 
@@ -15,6 +16,12 @@ app = typer.Typer()
 valid_inclusions = ['trigger', 'environment', 'run_steps', 'job', 'repository']
 
 
+def version_callback(called: bool):
+    if called:
+        typer.echo(f'dbtc version: {__version__}')
+        raise typer.Exit()
+
+
 def complete_inclusion(ctx, param, incomplete):
     for inclusion in valid_inclusions:
         if inclusion.startswith(incomplete):
@@ -34,6 +41,7 @@ API_KEY = typer.Option(
 CONNECTION_ID = typer.Option(
     ..., '--connection-id', '-c', help='Numeric ID of the connection.'
 )
+DO_NOT_TRACK = typer.Option(False, '--do-not-track', help='Turn off tracking')
 ENVIRONMENT_ID = typer.Option(
     ..., '--environment-id', '-e', help='Numeric ID of the connection.'
 )
@@ -103,6 +111,16 @@ UNIQUE_ID = typer.Option(
 )
 USER_ID = typer.Option(..., '--user-id', '-u', help='Numeric ID of the user.')
 
+VERSION = typer.Option(
+    None,
+    '--version',
+    '-v',
+    help='Show installed version of dbtc.',
+    callback=version_callback,
+    is_eager=True,
+)
+WEBHOOK_ID = typer.Option(..., '--webhook-id', '-w', help='String ID of the webhook')
+
 
 def _dbt_api_request(ctx: typer.Context, property: str, method: str, *args, **kwargs):
     instance = dbtc(**ctx.obj)
@@ -131,7 +149,10 @@ def common(
     api_key: Optional[str] = API_KEY,
     service_token: Optional[str] = TOKEN,
     host: Optional[str] = HOST,
+    do_not_track: Optional[bool] = DO_NOT_TRACK,
+    version: Optional[bool] = VERSION,
 ):
+    ctx.params.pop('version')
     ctx.obj = ctx.params
     pass
 
@@ -306,6 +327,14 @@ def create_user_group(
     _dbt_cloud_request(ctx, 'create_user_group', account_id, json.loads(payload))
 
 
+@app.command()
+def create_webhook(
+    ctx: typer.Context, account_id: int = ACCOUNT_ID, payload: str = PAYLOAD
+):
+    """Create a webhook."""
+    _dbt_cloud_request(ctx, 'create_webhook', account_id, json.loads(payload))
+
+
 @app.command()
 def deactivate_user_license(
     ctx: typer.Context,
@@ -391,6 +420,16 @@ def delete_user_group(
     _dbt_cloud_request(ctx, 'delete_user_group', account_id, group_id)
 
 
+@app.command()
+def delete_webhook(
+    ctx: typer.Context,
+    account_id: int = ACCOUNT_ID,
+    webhook_id: str = WEBHOOK_ID,
+):
+    """Delete a webhook."""
+    _dbt_cloud_request(ctx, 'delete_webhook', account_id, webhook_id)
+
+
 @app.command()
 def get_account(ctx: typer.Context, account_id: int = ACCOUNT_ID):
     """Get an account by its ID."""
@@ -813,21 +852,6 @@ def get_run_timing_details(
     )
 
 
-@app.command()
-def get_run_v4(
-    ctx: typer.Context,
-    account_id: int = ACCOUNT_ID,
-    run_id: int = RUN_ID,
-):
-    """Get specific run, from version 4"""
-    _dbt_cloud_request(
-        ctx,
-        'get_run_v4',
-        account_id,
-        run_id,
-    )
-
-
 @app.command()
 def get_user(
     ctx: typer.Context,
@@ -843,6 +867,16 @@ def get_user(
     )
 
 
+@app.command()
+def get_webhook(
+    ctx: typer.Context,
+    account_id: int = ACCOUNT_ID,
+    webhook_id: str = WEBHOOK_ID,
+):
+    """Get a webhook by its ID"""
+    _dbt_cloud_request(ctx, 'get_webhook', account_id=account_id, webhook_id=webhook_id)
+
+
 @app.command()
 def list_accounts(ctx: typer.Context):
     """List of accounts that your API Token is authorized to access."""
@@ -1120,6 +1154,23 @@ def list_users(
     )
 
 
+@app.command()
+def list_webhooks(
+    ctx: typer.Context,
+    account_id: int = ACCOUNT_ID,
+    offset: int = OFFSET,
+    limit: int = LIMIT,
+):
+    """List webhooks for a specific account."""
+    _dbt_cloud_request(
+        ctx,
+        'list_webhooks',
+        account_id,
+        offset=offset,
+        limit=limit,
+    )
+
+
 @app.command()
 def test_connection(
     ctx: typer.Context,
@@ -1137,6 +1188,21 @@ def test_connection(
     )
 
 
+@app.command()
+def test_webhook(
+    ctx: typer.Context,
+    account_id: int = ACCOUNT_ID,
+    webhook_id: str = WEBHOOK_ID,
+):
+    """Test a webhook."""
+    _dbt_cloud_request(
+        ctx,
+        'test_webhook',
+        account_id,
+        webhook_id,
+    )
+
+
 @app.command()
 def trigger_job(
     ctx: typer.Context,
@@ -1181,6 +1247,9 @@ def trigger_autoscaling_ci_job(
     delete_cloned_job: bool = typer.Option(
         True, help='Indicate whether cloned job should be deleted after triggering'
     ),
+    max_run_slots: int = typer.Option(
+        None, help='Number of run slots that should be available to this process'
+    ),
 ):
     """Trigger an autoscaling CI job to run."""
     _dbt_cloud_request(
@@ -1192,6 +1261,7 @@ def trigger_autoscaling_ci_job(
         should_poll=should_poll,
         poll_interval=poll_interval,
         delete_cloned_job=delete_cloned_job,
+        max_run_slots=max_run_slots,
     )
 
 
@@ -1344,5 +1414,22 @@ def update_repository(
     )
 
 
+@app.command()
+def update_webhook(
+    ctx: typer.Context,
+    account_id: int = ACCOUNT_ID,
+    webhook_id: str = WEBHOOK_ID,
+    payload: str = PAYLOAD,
+):
+    """Update a webhook."""
+    _dbt_cloud_request(
+        ctx,
+        'update_webhook',
+        account_id,
+        webhook_id,
+        json.loads(payload),
+    )
+
+
 def main():
     app()
